#!/bin/sh
# This script allows a 3rd party IDE to use cymcuelftool.exe to perform
# the post processing that is necessary to update the *.elf file
# generated by the linker into a complete memory image to use in
# programming the PSoC.
# NOTE: Please provide the path to the CyElfTool.
if [ "$4" == "cmsis" ]; then
for f in "$5/cymcuelftool.exe"
do
cp -f "$f" "$3/cymcuelftool.exe"
LAST_EXIT=$?
if [ $LAST_EXIT != 0 ]; then
    exit $LAST_EXIT
fi
done

OUT_FILE_NAME=$(basename "$1")
CURRENT_LINK_FILE_NAME="${OUT_FILE_NAME%.*}""_link.axf"
CURRENT_LINK_FILE=$(dirname "$1")/"$CURRENT_LINK_FILE_NAME"

mv -f "$1" "$CURRENT_LINK_FILE"
LAST_EXIT=$?
if [ $LAST_EXIT != 0 ]; then
    exit $LAST_EXIT
fi

# If you have changed the CortexM0p-based project executable output directory, then please provide your location here:
CORTEXM0P_OUTPUT_DIRECTORY=$3/Objects

SIGNED_LINK_FILENAME="${OUT_FILE_NAME%.*}""_signed.axf"
SIGNED_LINK_FILE=$(dirname "$CURRENT_LINK_FILE")"/$SIGNED_LINK_FILENAME"
EXTRA_LINK_FILE="$(find "$CORTEXM0P_OUTPUT_DIRECTORY" -maxdepth 1 -type f -name "*_link.axf" -a -not -name "$CURRENT_LINK_FILE_NAME")"

"$3/cymcuelftool.exe" --sign "$CURRENT_LINK_FILE" --output "$SIGNED_LINK_FILE"
LAST_EXIT=$?
if [ $LAST_EXIT != 0 ]; then
    exit $LAST_EXIT
fi
"$3/cymcuelftool.exe" --merge "$SIGNED_LINK_FILE" "${EXTRA_LINK_FILE%_link}" --output "$1"
LAST_EXIT=$?
if [ $LAST_EXIT != 0 ]; then
    exit $LAST_EXIT
fi
    exit
fi

if [ "$2" == "eclipse" ]; then
mv -f "$1" "$1_link.out"
LAST_EXIT=$?
if [ $LAST_EXIT != 0 ]; then
    exit $LAST_EXIT
fi
CURRENT_LINK_FILE="$1_link.out"
SIGNED_LINK_FILE="${CURRENT_LINK_FILE%_link.out}""_signed.out"
./cymcuelftool.exe --sign "$CURRENT_LINK_FILE" --output "$SIGNED_LINK_FILE"
LAST_EXIT=$?
if [ $LAST_EXIT != 0 ]; then
    exit $LAST_EXIT
fi
./cymcuelftool.exe --merge "$SIGNED_LINK_FILE" "$3" --output "$1"
LAST_EXIT=$?
if [ $LAST_EXIT != 0 ]; then
    exit $LAST_EXIT
fi
    exit
fi

